==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Bildinfo</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Strg+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Basisinformationen</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Zu Album hinzufügen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alle Bilder</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit hinzufügen</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Sie haben keine Berechtigung zum Ansehen des Bildes</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Änderungsdatum</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Aufnahmedatum</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtungsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtungsprogramm</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtungszeit</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blitz</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Blende</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brennweite</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max. Blendenöffnung</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Messmethode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Weißabgleich</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blitzbelichtungskorrektur</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linsenmodell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Farbraum</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramodell</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Abmessungen</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Schlagwort</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Größe</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>An Fenstergröße anpassen</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Text extrahieren</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigationsfenster anzeigen</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigationsfenster ausblenden</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinfo</translation>
    </message>
    <message>
        <source>day</source>
        <translation>Tag</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Neuen Namen eingeben</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Keine Bilddateien gefunden</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Bilddatei nicht gefunden</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Sie haben keine Berechtigung zum Ansehen der Datei</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.39.orig.tar.xz: image-editor-1.0.39/libimageviewer/translations/libimageviewer_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Bildinfo</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Strg+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Basisinformationen</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Zu Album hinzufügen</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Neues Album</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Alle Bilder</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Bild öffnen</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportieren</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Aus Album entfernen</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Favorit entfernen</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit hinzufügen</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Sie haben keine Berechtigung zum Ansehen des Bildes</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Änderungsdatum</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Dateigröße</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Aufnahmedatum</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Belichtungsmodus</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Belichtungsprogramm</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Belichtungszeit</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blitz</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Blende</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Brennweite</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Max. Blendenöffnung</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Messmethode</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Weißabgleich</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Blitzbelichtungskorrektur</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Linsenmodell</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Farbraum</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Kameramodell</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Abmessungen</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Schlagwort</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Größe</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>An Fenstergröße anpassen</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Text extrahieren</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gegen den Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Im Uhrzeigersinn drehen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diashow</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Umbenennen</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Navigationsfenster anzeigen</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Navigationsfenster ausblenden</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Als Hintergrundbild festlegen</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>In Dateiverwaltung anzeigen</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Bildinfo</translation>
    </message>
    <message>
        <source>day</source>
        <translation>Tag</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Bestätigen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Neuen Namen eingeben</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Wiedergabe</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Keine Bilddateien gefunden</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Bilddatei nicht gefunden</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>Sie haben keine Berechtigung zum Ansehen der Datei</translation>
    </message>
</context>
</TS>
